@@ -61,6 +61,7 @@ function smallHash($text)
  */
 function startsWith($haystack, $needle, $case = true)
 {
+    $needle = $needle ?? '';
     if ($case) {
         return (strcmp(substr($haystack, 0, strlen($needle)), $needle) === 0);
     }
@@ -180,7 +181,7 @@ function generateLocation($referer, $host, $loopTerms = [])
         $host = substr($host, 0, $pos);
     }
 
-    $refererHost = parse_url($referer, PHP_URL_HOST);
+    $refererHost = parse_url($referer, PHP_URL_HOST) ?? '';
     if (!empty($referer) && (strpos($refererHost, $host) !== false || startsWith('?', $refererHost))) {
         $finalReferer = $referer;
     }
@@ -197,7 +198,7 @@ function generateLocation($referer, $host, $loopTerms = [])
 function autoLocale($headerLocale)
 {
     // Default if browser does not send HTTP_ACCEPT_LANGUAGE
-    $locales = ['en_US', 'en_US.utf8', 'en_US.UTF-8'];
+    $locales = ['en_US.UTF-8', 'en_US.utf8', 'en_US'];
     if (! empty($headerLocale)) {
         if (preg_match_all('/([a-z]{2,3})[-_]?([a-z]{2})?,?/i', $headerLocale, $matches, PREG_SET_ORDER)) {
             $attempts = [];
@@ -292,7 +293,7 @@ function generate_api_secret($username, $salt)
  */
 function normalize_spaces($string)
 {
-    return preg_replace('/\s{2,}/', ' ', trim($string));
+    return preg_replace('/\s{2,}/', ' ', trim($string ?? ''));
 }
 
 /**
@@ -314,15 +315,18 @@ function format_date($date, $time = true, $intl = true)
     }
 
     if (! $intl || ! class_exists('IntlDateFormatter')) {
-        $format = $time ? '%c' : '%x';
-        return strftime($format, $date->getTimestamp());
+        $format = 'F j, Y';
+        if ($time) {
+            $format .= ' h:i:s A \G\M\TP';
+        }
+        return $date->format($format);
     }
-
     $formatter = new IntlDateFormatter(
         setlocale(LC_TIME, 0),
         IntlDateFormatter::LONG,
         $time ? IntlDateFormatter::LONG : IntlDateFormatter::NONE
     );
+    $formatter->setTimeZone($date->getTimezone());
 
     return $formatter->format($date);
 }
