@@ -85,6 +85,7 @@ class Bookmark
             $this->updated = $data['updated'];
         }
         $this->private = ($data['private'] ?? false) ? true : false;
+        $this->additionalContent = $data['additional_content'] ?? [];
 
         return $this;
     }
@@ -483,7 +484,7 @@ class Bookmark
      *
      * @return $this
      */
-    public function addAdditionalContentEntry(string $key, $value): self
+    public function setAdditionalContentEntry(string $key, $value): self
     {
         $this->additionalContent[$key] = $value;
 
@@ -516,6 +517,16 @@ class Bookmark
         }
     }
 
+    /**
+     * Add a tag in tags list.
+     *
+     * @param string $tag
+     */
+    public function addTag(string $tag): self
+    {
+        return $this->setTags(array_unique(array_merge($this->getTags(), [$tag])));
+    }
+
     /**
      * Delete a tag from tags list.
      *
@@ -523,7 +534,7 @@ class Bookmark
      */
     public function deleteTag(string $tag): void
     {
-        if (($pos = array_search($tag, $this->tags ?? [])) !== false) {
+        while (($pos = array_search($tag, $this->tags ?? [])) !== false) {
             unset($this->tags[$pos]);
             $this->tags = array_values($this->tags);
         }
